/*------------------------------------------------------------------------------
 * MDK Middleware - Component ::USB:Device
 * Copyright (c) 2004-2019 Arm Limited (or its affiliates). All rights reserved.
 *------------------------------------------------------------------------------
 * Name:    WinUSB_Echo.c
 * Purpose: USB Device WinUSB Device Echo Bulk Out to Bulk In
 *----------------------------------------------------------------------------*/

#include "rl_usb.h"                // Keil.MDK-Pro::USB:CORE

#include "Board_GLCD.h"                 // ::Board Support:Graphic LCD
#include "GLCD_Config.h"                // Keil.STM32F769I-EVAL::Board Support:Graphic LCD

#include "stm32f7xx_hal.h"
#include "stm32f769i_eval_io.h"

// Main stack size must be multiple of 8 Bytes
#define APP_MAIN_STK_SZ (1024U)
uint64_t app_main_stk[APP_MAIN_STK_SZ / 8];
const osThreadAttr_t app_main_attr = {
  .stack_mem  = &app_main_stk[0],
  .stack_size = sizeof(app_main_stk)
};

extern    GLCD_FONT GLCD_Font_6x8;
extern    GLCD_FONT GLCD_Font_16x24;

/*----------------------------------------------------------------------------
 * Application main thread
 *---------------------------------------------------------------------------*/
__NO_RETURN void app_main (void *argument) {
  (void)argument;

  GLCD_Initialize         ();
  GLCD_SetBackgroundColor (GLCD_COLOR_BLUE);
  GLCD_SetForegroundColor (GLCD_COLOR_WHITE);
  GLCD_ClearScreen        ();
  GLCD_SetFont            (&GLCD_Font_16x24);
  GLCD_DrawString         (0U, 0U*24U, "          USB Device          ");
  GLCD_DrawString         (0U, 1U*24U, "         WinUSB Class         ");
  GLCD_DrawString         (0U, 2U*24U, "      Custom Class Example    ");
  GLCD_DrawString         (0U, 4U*24U, "OTG_FS1: Echo on Bulk EP 1    ");
  GLCD_DrawString         (0U, 5U*24U, "OTG_HS:  Echo on Bulk EP 1    ");
  GLCD_DrawString         (0U, 8U*24U, "       Keil Tools by ARM      ");
  GLCD_DrawString         (0U, 9U*24U, "         www.keil.com         ");

  /* Turn off USB Host VBUS power driving pin, so VBUS sensing can be used    */
  BSP_IO_Init();
  BSP_IO_ConfigPin(IO_PIN_7, IO_MODE_OFF);

  USBD_Initialize         (0);          /* USB Device 0 Initialization        */
  USBD_Connect            (0);          /* USB Device 0 Connect               */

  USBD_Initialize         (1);          /* USB Device 1 Initialization        */
  USBD_Connect            (1);          /* USB Device 1 Connect               */

  osThreadExit();
}
